Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

01:45.834 total execution time for 8 files from examples04-fermi3d:

Example | Time | Mem (MB)
--- | --- | ---
Plotting fermi3d isovalue_gif (`plot_fermi3d_isovalue_gif.py`) | 00:30.366 | 0.0
Plotting fermi3d isoslider (`plot_fermi3d_isoslider.py`) | 00:29.115 | 0.0
Plotting fermi3d cross_section (`plot_fermi3d_cross_section.py`) | 00:15.681 | 0.0
Plotting fermi3d spin_texture (`plot_fermi3d_spin_texture.py`) | 00:10.006 | 0.0
Plotting fermi3d spin-polarized (`plot_fermi3d_spin-polarized.py`) | 00:07.379 | 0.0
Plotting fermi3d plain (`plot_fermi3d_plain.py`) | 00:04.578 | 0.0
Plotting with Configurations in pyprocar (`plot_fermi3d_configurations.py`) | 00:04.564 | 0.0
Showing how to get van alphen fequencies from the fermi surface (`plot_de_hass_van_alphen.py`) | 00:04.146 | 0.0